package org.onosproject.net.tunnel;

import java.util.Objects;

/**
 * Represents for a unique tunnel name. TunnelId is generated by ONOS while
 * TunnelName is given by producer. The consumer can borrow tunnels with
 * TunnelId or TunnelName.
 */
public final class TunnelName {
    private final String str;

    // Default constructor for serialization
    private TunnelName(String tunnelName) {
        this.str = tunnelName;
    }


    /**
     * Creates a tunnel name using the supplied URI string.
     *
     * @param tunnelName tunnel name string
     * @return tunnel name object
     */
    public static TunnelName tunnelName(String tunnelName) {
        return new TunnelName(tunnelName);
    }

    /**
     * The string of tunnel name.
     *
     * @return the string of tunnel name
     */
    public String value() {
        return str;
    }

    @Override
    public int hashCode() {
        return Objects.hash(str);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof TunnelName) {
            final TunnelName that = (TunnelName) obj;
            return this.getClass() == that.getClass()
                    && Objects.equals(this.str, that.str);
        }
        return false;
    }

    @Override
    public String toString() {
        return str;
    }
}
